==> huaweicloudsdkdli-3.1.87-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/list_catalogs_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCatalogsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_success': 'bool',
        'total_count': 'int',
        'catalogs': 'list[CatalogEntity]'
    }

    attribute_map = {
        'is_success': 'is_success',
        'total_count': 'total_count',
        'catalogs': 'catalogs'
    }

    def __init__(self, is_success=None, total_count=None, catalogs=None):
        """ListCatalogsResponse

        The model defined in huaweicloud sdk

        :param is_success: 是否成功
        :type is_success: bool
        :param total_count: catalog总数量
        :type total_count: int
        :param catalogs: 项目下所有catalog信息
        :type catalogs: list[:class:`huaweicloudsdkdli.v1.CatalogEntity`]
        """
        
        super(ListCatalogsResponse, self).__init__()

        self._is_success = None
        self._total_count = None
        self._catalogs = None
        self.discriminator = None

        if is_success is not None:
            self.is_success = is_success
        if total_count is not None:
            self.total_count = total_count
        if catalogs is not None:
            self.catalogs = catalogs

    @property
    def is_success(self):
        """Gets the is_success of this ListCatalogsResponse.

        是否成功

        :return: The is_success of this ListCatalogsResponse.
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """Sets the is_success of this ListCatalogsResponse.

        是否成功

        :param is_success: The is_success of this ListCatalogsResponse.
        :type is_success: bool
        """
        self._is_success = is_success

    @property
    def total_count(self):
        """Gets the total_count of this ListCatalogsResponse.

        catalog总数量

        :return: The total_count of this ListCatalogsResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListCatalogsResponse.

        catalog总数量

        :param total_count: The total_count of this ListCatalogsResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def catalogs(self):
        """Gets the catalogs of this ListCatalogsResponse.

        项目下所有catalog信息

        :return: The catalogs of this ListCatalogsResponse.
        :rtype: list[:class:`huaweicloudsdkdli.v1.CatalogEntity`]
        """
        return self._catalogs

    @catalogs.setter
    def catalogs(self, catalogs):
        """Sets the catalogs of this ListCatalogsResponse.

        项目下所有catalog信息

        :param catalogs: The catalogs of this ListCatalogsResponse.
        :type catalogs: list[:class:`huaweicloudsdkdli.v1.CatalogEntity`]
        """
        self._catalogs = catalogs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCatalogsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.93-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/list_catalogs_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCatalogsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_success': 'bool',
        'total_count': 'int',
        'catalogs': 'list[Catalog]'
    }

    attribute_map = {
        'is_success': 'is_success',
        'total_count': 'total_count',
        'catalogs': 'catalogs'
    }

    def __init__(self, is_success=None, total_count=None, catalogs=None):
        """ListCatalogsResponse

        The model defined in huaweicloud sdk

        :param is_success: 是否成功
        :type is_success: bool
        :param total_count: catalog总数量
        :type total_count: int
        :param catalogs: 项目下所有catalog信息
        :type catalogs: list[:class:`huaweicloudsdkdli.v1.Catalog`]
        """
        
        super(ListCatalogsResponse, self).__init__()

        self._is_success = None
        self._total_count = None
        self._catalogs = None
        self.discriminator = None

        if is_success is not None:
            self.is_success = is_success
        if total_count is not None:
            self.total_count = total_count
        if catalogs is not None:
            self.catalogs = catalogs

    @property
    def is_success(self):
        """Gets the is_success of this ListCatalogsResponse.

        是否成功

        :return: The is_success of this ListCatalogsResponse.
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """Sets the is_success of this ListCatalogsResponse.

        是否成功

        :param is_success: The is_success of this ListCatalogsResponse.
        :type is_success: bool
        """
        self._is_success = is_success

    @property
    def total_count(self):
        """Gets the total_count of this ListCatalogsResponse.

        catalog总数量

        :return: The total_count of this ListCatalogsResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListCatalogsResponse.

        catalog总数量

        :param total_count: The total_count of this ListCatalogsResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def catalogs(self):
        """Gets the catalogs of this ListCatalogsResponse.

        项目下所有catalog信息

        :return: The catalogs of this ListCatalogsResponse.
        :rtype: list[:class:`huaweicloudsdkdli.v1.Catalog`]
        """
        return self._catalogs

    @catalogs.setter
    def catalogs(self, catalogs):
        """Sets the catalogs of this ListCatalogsResponse.

        项目下所有catalog信息

        :param catalogs: The catalogs of this ListCatalogsResponse.
        :type catalogs: list[:class:`huaweicloudsdkdli.v1.Catalog`]
        """
        self._catalogs = catalogs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCatalogsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
